@@ -24,7 +24,8 @@ Plot data using a style adjusted to APS journals:
 >>> with plt.style.context('qutil.plotting.publication_aps_tex'):
 ...    plt.plot([1, 2], [3, 4], label='presentation style')
 ...    plt.legend()
-...    plt.show()
+...    plt.show(block=False)
+[...
 
 Plot data using all available custom styles:
 
@@ -36,7 +37,7 @@ Plot data using all available custom styles:
 ...     with plt.style.context(style):
 ...         plt.plot([1, 2], [3, 4])
 ...         plt.title(file.stem)
-...         plt.show()
-
+...         plt.show(block=False)
+[...
 """
 from .core import *
